<?php
/**
 * WP Helpdesk Integration.
 *
 * WP Helpdesk Integration plugin file.
 *
 * @package   Smackcoders\SF
 * @copyright Copyright (C) 2010-2020, Smackcoders Inc - info@smackcoders.com
 * @license   http://www.gnu.org/licenses/gpl-3.0.html GNU General Public License, version 3 or higher
 *
 * @wordpress-plugin
 * Plugin Name: WP Helpdesk Integration
 * Version:     1.3
 * Plugin URI:  https://www.smackcoders.com/wp-leads-builder-any-crm-pro.html
 * Description: Send contact, support and WP User informations captured with simple Webforms & Contact Form 7 in WordPress to Freshdesk, Zoho Support & Zendesk and Vtiger Tickets module. Embed forms in Posts, Pages & Widgets.
 * Author:      Smackcoders
 * Author URI:  https://www.smackcoders.com/wordpress.html
 * Text Domain: wp-helpdesk-integration
 * Domain Path: /languages
 * License:     GPL v3
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
ob_start();

define('WP_HELPDESK_INTEGRATION_URL', 'http://www.smackcoders.com/store/');
define('WP_HELPDESK_INTEGRATION_NAME', 'Helpdesk Integration');
define('WP_HELPDESK_INTEGRATION_SLUG', 'wp-helpdesk-integration');
define('WP_HELPDESK_INTEGRATION_SETTINGS', 'WP Helpdesk Integration');
define('WP_HELPDESK_INTEGRATION_VERSION', '1.3');
define('WP_HELPDESK_INTEGRATION_DIR', WP_PLUGIN_URL . '/' . WP_HELPDESK_INTEGRATION_SLUG . '/');
define('WP_HELPDESK_INTEGRATION_DIRECTORY', plugin_dir_path( __FILE__ ));
define('WP_HELPDESK_INTEGRATION_PLUG_URL',site_url().'/wp-admin/admin.php?page='.WP_HELPDESK_INTEGRATION_SLUG.'/index.php');

add_action('plugins_loaded','SmackHelpDeskIntegrationLoadLanguages');
function SmackHelpDeskIntegrationLoadLanguages(){
	$wp_helpdesk_integration_pro_lang_dir = dirname( plugin_basename( __FILE__ ) ) . '/languages/';
	load_plugin_textdomain( WP_HELPDESK_INTEGRATION_SLUG , false, $wp_helpdesk_integration_pro_lang_dir );
}
if (!class_exists('SkinnyControllerHelpDeskIntegration')) {
	require_once('lib/skinnymvc/controller/SkinnyController.php');
}

require_once("includes/Data.php");
require_once("includes/ContactFormPlugins.php");
$ContactFormPlugins = new SmackHelpDeskUIHelper();
$ActivePlugin = $ContactFormPlugins->getActivePlugin();
$get_debug_option = get_option("smack_whi_{$ActivePlugin}_settings");

if(!isset($get_debug_option['debugmode'])) {
	error_reporting(0);
	ini_set('display_errors', 'Off');
}


if(isset( $_REQUEST['portal_type'] ))
{
	require_once("includes/{$_REQUEST['portal_type']}Functions.php");
}
else
{
	require_once("includes/{$ActivePlugin}Functions.php");
}

if(isset( $_REQUEST['code'] ) && (sanitize_text_field($_REQUEST['code']) != '') && !isset($config['id_token']) )
{
	$config = get_option('smack_whi_zohodesk1_settings');
	include_once(WP_HELPDESK_INTEGRATION_DIRECTORY.'lib/SmackZohoSupportApi.php');
	$code = sanitize_text_field( $_REQUEST['code'] );
	$test = new SmackZohoSupportApi();
	$response = $test->ZohoGet_Getaccess( $config , $code);
	$access_token = $response['access_token'];
	$refresh_token = $response['refresh_token'];
	if (!isset($access_token) || $access_token == "") {
		//  die("Error - access token missing from response!");
	}
	$_SESSION['access_token'] = $access_token;
	$_SESSION['instance_url'] = $instance_url;
	$config['access_token'] = $access_token;
	$config['refresh_token'] = $refresh_token;
	$config['api_domain'] = $response['api_domain'];
	$config['key'] = $config['key'];
	$config['secret'] = $config['secret'];
	$config['org_id'] = $config['org_id'];
	$config['callback'] = $config['callback'];
	$config['domain'] = $config['domain'];
	
	update_option('smack_whi_zohodesk1_settings' , $config);
}

require_once('lib/skinnymvc/controller/SkinnyController.php');
require_once('includes/SmackHelpDeskIntegrationHelper.php');
require_once("templates/SmackContactFormGenerator.php");
require_once('includes/Functions.php');

# Activation & Deactivation
register_activation_hook(__FILE__, array('SmackHelpDeskIntegrationHelper', 'activate') );
register_deactivation_hook(__FILE__, array('SmackHelpDeskIntegrationHelper', 'deactivate') );

function SmackHelpDeskIntegrationMenu()
{
	add_menu_page(WP_HELPDESK_INTEGRATION_SETTINGS, WP_HELPDESK_INTEGRATION_NAME, 'manage_options',  __FILE__, array('SmackHelpDeskIntegrationHelper','output_fd_page'), WP_HELPDESK_INTEGRATION_DIR . "/images/WPHelpDeskIntegration.png");
}
add_action ( "admin_menu", "SmackHelpDeskIntegrationMenu" );

function SmackHelpDeskIntegrationInitActions()
{
	if (isset($_REQUEST['page']) && (sanitize_text_field($_REQUEST['page']) == WP_HELPDESK_INTEGRATION_SLUG.'/index.php' || $_REQUEST['page'] == 'page')) {
		wp_enqueue_script('jquery');
		wp_enqueue_style('main-style', plugins_url('css/mainstyle.css', __FILE__));
		wp_enqueue_style('jquery-ui', plugins_url('css/jquery-ui.css', __FILE__));
		wp_enqueue_style('helpdesk-integration-bootstrap-css', plugins_url('css/bootstrap.css', __FILE__));
		wp_enqueue_style('helpdesk-integration-font-awesome-css', plugins_url('css/font-awesome/css/font-awesome.css', __FILE__));
		wp_enqueue_style('magnific-popup.css', plugins_url('css/magnific-popup.css', __FILE__));
		wp_enqueue_style('jquery-confirm.min.css', plugins_url('css/jquery-confirm.min.css', __FILE__));
		wp_register_script('helpdesk-jquery', plugins_url('js/basicaction.js', __FILE__));
		wp_enqueue_script('helpdesk-jquery');
		wp_register_script('bootstrap-modal-min-js', plugins_url('js/bootstrap-modal.min.js', __FILE__));
		wp_enqueue_script('bootstrap-modal-min-js');
		wp_register_script('magnific-popup', plugins_url('js/jquery.magnific-popup.js', __FILE__));
		wp_enqueue_script('magnific-popup');
		wp_register_script('jquery-confirm.min.js', plugins_url('js/jquery-confirm.min.js', __FILE__));
		wp_enqueue_script('jquery-confirm.min.js');
	}
}

function SmackHelpDeskIntegrationFrontEndInitActions()
{
	if(!is_admin())
	{
		global $HelperObj;
		$HelperObj = new SmackHelpDeskIntegrationHelper;
		$activatedplugin = $HelperObj->ActivatedPlugin;
		$config = get_option("SmackHelpDeskCaptchaSettings");
		wp_enqueue_script('jquery-ui-datepicker');
		wp_enqueue_style('jquery-ui' , plugins_url('css/jquery-ui.css', __FILE__) );
		wp_enqueue_style('front-end-styles' , plugins_url('css/frontendstyles.css', __FILE__) );
		wp_enqueue_style('datepicker' , plugins_url('css/datepicker.css', __FILE__) );
	
	}
}

add_action('init' , 'SmackHelpDeskIntegrationFrontEndInitActions');
add_action('admin_init', 'SmackHelpDeskIntegrationInitActions');
$check_sync_value = get_option( 'SmackHelpDeskUserSyncOption' );

if( $check_sync_value == "On" ){
	add_action( 'profile_update', array( 'SmackHelpDeskUserDataCapture' , 'capture_updating_users' ) );
	add_action( 'user_register', array( 'SmackHelpDeskUserDataCapture' , 'capture_registering_users' ) );
}
$active_plugins = get_option( "active_plugins" );

function smack_whi_TFA_auth_save()
{
	$TFA_Authtoken_value = sanitize_text_field( $_REQUEST['authtoken']);
	update_option("SmackHelpDeskTFA_zoho_authtoken" , $TFA_Authtoken_value );
	print_r( $TFA_Authtoken_value);
	die;
}
add_action('wp_ajax_smack_whi_TFA_auth_save' , 'smack_whi_TFA_auth_save' );

function SmackHelpDeskSaveConfiguration( )
{
	require_once( 'modules/Settings/actions/SmackHelpDeskSaveConfiguration.php' );
	die;
}
add_action( 'wp_ajax_SmackHelpDeskSaveConfiguration' , 'SmackHelpDeskSaveConfiguration' );

function SmackHelpDeskUserAutoSyncSettings()
{
	require_once( 'templates/save-sync-value.php' );
	die;
}
add_action( 'wp_ajax_SmackHelpDeskUserAutoSyncSettings' , 'SmackHelpDeskUserAutoSyncSettings' );

function SmackHelpDeskChangeActivePortal()
{
	require_once("templates/plugin-select.php");
	die;
}


function SmackHelpDeskCustomMenuOrder( $menu_order ) {
	return array(
		'index.php',
		'edit.php',
		'edit.php?post_type=page',
		'upload.php',
		WP_HELPDESK_INTEGRATION_SLUG . '/index.php',
		'wp-leads-builder-any-crm-pro/index.php',
	);
}
add_filter( 'custom_menu_order', '__return_true' );
add_filter( 'menu_order', 'SmackHelpDeskCustomMenuOrder' );

add_action('wp_ajax_SmackHelpDeskChangeActivePortal', 'SmackHelpDeskChangeActivePortal');

SmackHelpDeskIntegrationHelper::checkVersion();